## Sim-Engine
Helps to create games without limiting you

### Advantages
* **Speed** - You will very quickly start developing without paying attention to the infrastructure (but you can also tailor it to your needs)
* **Connectability** - You can quickly connect the engine to an already created game
* **Flexibility** - You are not even limited to 2 or 3 dimensions!
* **Controllability** - You can incredibly deftly operate with the logic of your game
* **Fullness** - Integration with pygame rendering solution

### Installation
`pip install sim32`
